@@ -1,16 +1,15 @@
 //! Read and write the git packet line wire format without copying it.
 //!
-//! For reading the packet line format use the [`Provider`], and for writing the `Writer`.
-#![forbid(unsafe_code)]
-#![deny(rust_2018_idioms, missing_docs)]
+//! For reading the packet line format use the [`StreamingPeekableIter`], and for writing the `Writer`.
+#![deny(unsafe_code, rust_2018_idioms, missing_docs)]
 
-pub(crate) const U16_HEX_BYTES: usize = 4;
-pub(crate) const MAX_DATA_LEN: usize = 65516;
-pub(crate) const MAX_LINE_LEN: usize = MAX_DATA_LEN + U16_HEX_BYTES;
-pub(crate) const FLUSH_LINE: &[u8] = b"0000";
-pub(crate) const DELIMITER_LINE: &[u8] = b"0001";
-pub(crate) const RESPONSE_END_LINE: &[u8] = b"0002";
-pub(crate) const ERR_PREFIX: &[u8] = b"ERR ";
+const U16_HEX_BYTES: usize = 4;
+const MAX_DATA_LEN: usize = 65516;
+const MAX_LINE_LEN: usize = MAX_DATA_LEN + U16_HEX_BYTES;
+const FLUSH_LINE: &[u8] = b"0000";
+const DELIMITER_LINE: &[u8] = b"0001";
+const RESPONSE_END_LINE: &[u8] = b"0002";
+const ERR_PREFIX: &[u8] = b"ERR ";
 
 /// One of three side-band types allowing to multiplex information over a single connection.
 #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone, Copy)]
@@ -25,16 +24,18 @@ pub enum Channel {
 }
 
 ///
-pub mod borrowed;
-pub use borrowed::Borrowed as PacketLine;
+pub mod immutable;
+pub use immutable::PacketLine;
 
 ///
-pub mod provider;
+pub mod read;
 #[doc(inline)]
-pub use provider::Provider;
+pub use read::StreamingPeekableIter;
 
 ///
+#[cfg(any(feature = "async-io", feature = "blocking-io"))]
 pub mod write;
+#[cfg(any(feature = "async-io", feature = "blocking-io"))]
 #[doc(inline)]
 pub use write::Writer;
 
@@ -44,3 +45,6 @@ pub mod decode;
 pub use decode::all_at_once as decode;
 /// Utilities to encode different kinds of packet lines
 pub mod encode;
+
+#[cfg(all(feature = "async-io", feature = "blocking-io"))]
+compile_error!("Cannot set both 'blocking-io' and 'async-io' features as they are mutually exclusive");
